@@ -1,5 +1,5 @@
-#  tests for pycurl-7.43.0.6-py37h8b18dd5_1 (this is a generated file);
-print('===== testing package: pycurl-7.43.0.6-py37h8b18dd5_1 =====');
+#  tests for pycurl-7.44.1-py37h8b18dd5_1 (this is a generated file);
+print('===== testing package: pycurl-7.44.1-py37h8b18dd5_1 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import curl
@@ -21,7 +21,7 @@ assert b'Anaconda' in buf.getvalue()
 buf.close()
 #  --- run_test.py (end) ---
 
-print('===== pycurl-7.43.0.6-py37h8b18dd5_1 OK =====');
+print('===== pycurl-7.44.1-py37h8b18dd5_1 OK =====');
 print("import: 'curl'")
 import curl
 
